from typing import List


def parse_query_string(query_string: str) -> dict:
    _query_dict = { 
        _each.split('=')[0]: _each.split('=')[1] for _each in query_string.split('&') if _each and len(_each.split('=')) > 1
    }
    return _query_dict


def get_lower_from_list(upper_array_items: List[str]) -> List[str]:
    return list(map(lambda x: x.lower(), upper_array_items))


from utils.parsers import parse_query_string, get_lower_from_list


def test_parse_query_string():
    params_as_string = 'q=test&search=true&page=10'
    parsed_data = parse_query_string(params_as_string)
    assert isinstance(parsed_data, dict)
    assert parsed_data['q'] == 'test'
    assert parsed_data['search'] == 'true'
    assert parsed_data['page'] == '10'

def test_get_lower_from_list():
    data = get_lower_from_list(['A', 'b', 'C'])
    assert isinstance(data, list)
    assert data == ['a', 'b', 'c']



from typing import Any
from webob import Request, Response


def generic_no_access_view(request: Request, response: Response, **kwargs) -> dict:
    response.status_code = 403
    response.content_type = 'application/json'
    return {
        'status': 403,
        'message': 'No Access',
    }

def generic_method_not_allowed_view(request: Request, response: Response, **kwargs) -> dict:
    response.status_code = 405
    response.content_type = 'application/json'
    return {
        'status': 405,
        'message': 'Method Not Allowed',
    }
